<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;

use Teknisa\CNC\Services;
use Teknisa\Libs\Util\Environment;

class Cnc02700TaxaServEstabelecimento extends \Teknisa\CNC\Controllers\TeknisaCrud {
	protected $service;
	protected $environment;
	
	public function __construct (Services\Cnc02700TaxaServEstabelecimentoService $service, Environment $environment) {
        $this->service = $service;
        $this->environment = $environment;
	}

	public function getEstabelecTaxaServ(DTO\Request $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $resultadoFiltrado = $this->service->getEstabelecTaxaServ();

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc02700_taxa_servico_estabelecimento_select', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function getEstabelecTaxaServRow(DTO\Request $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $resultadoFiltrado = $this->service->getEstabelecTaxaServRow($params);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc02700_taxa_servico_estabelecimento_select_row', $resultadoFiltrado));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
	
	public function saveEstabelecTaxaServ (DTO\Request $request, DTO\Response $response) {
	    try {
    	    $rows = $request->getDataSet()->getRows();
    	    
    	    foreach ($rows as $row) {
    	        if (is_object($row))
                    $row = (array) $row;
                
                $row["NRORG"] = $this->environment->getNrOrgTrab();
                $row["IDATIVO"] = "S";
                $row["DTULTATU"] = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
                $row["CDOPERULTATU"] = $this->environment->getCdOperador();
                $this->service->saveEstabelecTaxaServ($row);
                $resultadoFiltrado = $this->service->getEstabelecTaxaServRow($row);
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc02700_taxa_servico_estabelecimento_select_row', $resultadoFiltrado));
    	    }
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}
	
	public function gettpAjusteAdm (DTO\Request\Filter $request, DTO\Response $response) {
	    try {
	        $dataSet = $this->service->gettpAjusteAdm();
	        $response->addDataSet(new DataSet('cnc02700_taxa_servico_estabelecimento_tpAjusteServ', $dataSet));
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}
	
	public function gettpAjustesServ (DTO\Request\Filter $request, DTO\Response $response) {
		try {
			$dataSet = $this->service->gettpAjustesServ();
			$response->addDataSet(new DataSet('cnc02700_taxa_servico_estabelecimento_tpAjusteAdm', $dataSet));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}

}