<?php

namespace Teknisa\CNC\Services;

use Teknisa\CNC\Utilities;
use Teknisa\CNC\Factories;

class Cnc01500AjustesAdquirentes {

	protected $entityManager;
	protected $util;
	protected $ajustAdqFactory;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager, Utilities\UtilCNC $util, Factories\Cnc01500AjustesAdquirenteFactory $ajustAdqFactory)  {
		$this->entityManager     = $entityManager;
		$this->util              = $util;
		$this->ajustAdqFactory  = $ajustAdqFactory;
	}

	public function getAdjustmentAqcuires($params) {
        if ($params["intervalo"] === 'M') {
            $dateDiff = date_create($params["MESINI"])->diff(date_create($params["MESFIN"]));
            
            if ($dateDiff->invert == 1)
                throw new \Exception('MESERROR',1);
            if ($dateDiff->m > 12)
                throw new \Exception('MESEXCEDEU',2);
                
            $params["DTCREDITOINI"] = $params["MESINI"];
            $params["DTCREDITOFIN"] = $params["MESFIN"];
        } else {
            $dateDiff = date_create($params["DTCREDITO"][0])->diff(date_create($params["DTCREDITO"][1]));
            
            if ($dateDiff->d > 14)
                throw new \Exception('DIAERROR',1);
                
            $params["DTCREDITOINI"] = $params["DTCREDITO"][0];
            $params["DTCREDITOFIN"] = $params["DTCREDITO"][1];
        }
        
        $params["TNRADQUIRENTE"] = null;
        if ($params["NRADQUIRENTE"] === "Todas") {
            $params["TNRADQUIRENTE"] = 'T';
            $params["NRADQUIRENTE"] = null;
        }
        $params["TNRESTABELEC"] = null;
        if ($params["NRESTABELEC"] === "Todas") {
            $params["TNRESTABELEC"] = 'T';
            $params["NRESTABELEC"] = null;
        }
        
        is_null($params["DTVENDA"][0]) ? $params["TDTVENDA"] = "T" : $params["TDTVENDA"] = null;
        
        return $this->ajustAdqFactory->getAdjustmentAqcuires(array(
            ':P_NRESTABELEC'   => $params["NRESTABELEC"],
            ':P_TNRESTABELEC'  => $params["TNRESTABELEC"],
            ':P_NRADQUIRENTE'  => $params["NRADQUIRENTE"],
            ':P_TNRADQUIRENTE' => $params["TNRADQUIRENTE"],
            ':DTVENDAINI'      => $params["DTVENDA"][0],
            ':DTVENDAFIN'      => $params["DTVENDA"][1],
            ':P_TDTVENDA'      => $params["TDTVENDA"],
            ':DTCREDITOINI'    => date_create($params["DTCREDITOINI"])->format("d/m/Y"),
            ':DTCREDITOFIN'    => date_create($params["DTCREDITOFIN"])->format("d/m/Y"),
            ':P_INTAJUST'      => $params["intervalo"]
        ));
    }
    
    public function chartDetails ($params) {
        $params["TNRADQUIRENTE"] = null;
        if ($params["NRADQUIRENTE"] === "Todas") {
            $params["TNRADQUIRENTE"] = 'T';
            $params["NRADQUIRENTE"] = null;
        }
        
        $params["TNRESTABELEC"] = null;
        if ($params["NRESTABELEC"] === "Todas") {
            $params["TNRESTABELEC"] = 'T';
            $params["NRESTABELEC"] = null;
        }
        
        is_null($params["DTVENDA"]["start"]) ? $params["TDTVENDA"] = "T" : $params["TDTVENDA"] = null;
        
        return $this->ajustAdqFactory->chartDetails(array(
            ":NRORG"        => $params["NRORG"],
            ":NRESTABELEC"  => $params["NRESTABELEC"],
            ":TNRESTABELEC" => $params["TNRESTABELEC"],
            ":NRADQUIRENTE" => $params["NRADQUIRENTE"],
            ":TNRADQUIRENTE"=> $params["TNRADQUIRENTE"],
            ":DTVENDAINI"   => $params["DTVENDA"]["start"],
            ":DTVENDAFIN"   => $params["DTVENDA"]["end"],
            ":TDTVENDA"     => $params["TDTVENDA"],
            ":DTCREDITOINI" => date_create($params["DTCREDITO"][0])->format("d/m/Y"),
            ":DTCREDITOFIN" => date_create($params["DTCREDITO"][1])->format("d/m/Y")
        ));
    }
    
}